@@ -28,7 +28,7 @@ while getopts "bi:mp:" opt; do
 done
 
 SRCPATH=$(dirname $BASH_SOURCE)
-PROJVER=${PROJVER:-4.9.3 5.1.0 5.2.0 6.2.1 6.3.2 7.0.1 7.2.1 8.0.0 8.2.1 9.0.0 9.3.1}
+PROJVER=${PROJVER:-6.3.1 6.3.2 7.0.1 7.2.1 8.0.0 8.2.1 9.0.0 9.5.0}
 
 URL=https://download.osgeo.org/proj/proj
 
@@ -56,7 +56,7 @@ do
     curl $URL-$ver.tar.gz | tar -xz --directory=$TMPDIR
     cd $TMPDIR/proj-$ver
     if (( `echo $ver | sed 's/\..*//'` < 8 )); then # pkgconfig supported with cmake since 8.0.0
-      ./configure --prefix=$PREFIX/proj-$ver; make -j$(nproc); make install
+      CC=gcc-12 CXX=g++-12 ./configure --prefix=$PREFIX/proj-$ver; make -j$(nproc); make install
     else
       mkdir build; cd build
       cmake -DCMAKE_INSTALL_PREFIX=$PREFIX/proj-$ver -DBUILD_APPS=OFF -DBUILD_TESTING=OFF ..; make -j$(nproc); make install
