@@ -28,7 +28,6 @@
 
 #include "thconfig.h"
 #include "therion.h"
-#include "thparse.h"
 #include "thlang.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -160,7 +159,7 @@ thconfig::thconfig()
   thbuffer * tmpbf = &(this->bf1);
   // set search path according to Windows registers
   tmpbf->guarantee(1024);
-  DWORD type, length = 1024;
+  DWORD type = 0, length = 1024;
   HKEY key;
   bool loaded_ok = true;
 	if (RegOpenKey(HKEY_LOCAL_MACHINE,"SOFTWARE\\Therion",&key) != ERROR_SUCCESS) {
