@@ -110,7 +110,7 @@ class thconfig {
   thexporter exporter;  ///< Data exporter.
   thselector selector;  ///< Database selector.
 
-  double ibbx[4]; ///< Input bounding box.
+  double ibbx[4] = {}; ///< Input bounding box.
   bool ibbx_def; ///< Input bounding box defined.
 
   bool m_decl_out_of_geomag_range; ///< Whether declination out of geomag model range.
