@@ -26,7 +26,6 @@
  */
 
 #include "thcs.h"
-#include "thparse.h"
 #include "thcsdata.h"
 #include "thexception.h"
 #include "thproj.h"
@@ -123,24 +122,13 @@ const thcsdata * thcs_get_data(int cs) {
 	rv.params = params;
 	rv.prjname = prjname;
 	strcpy(prjname, thcs_get_name(cs));
-	rv.prjspec = "";
 	rv.swap = false;
 	if (cs > TTCS_ESRI) {
-	  std::snprintf(params, sizeof(params), "+init=esri:%d", cs - TTCS_ESRI);
-      if (esri_labels.find(cs - TTCS_ESRI) != esri_labels.end()) {
-        rv.prjname = esri_labels[cs - TTCS_ESRI];
-      } else {
-        thcs_get_label(params).copy(prjname, 200, 0);
-      }
+	  std::snprintf(params, sizeof(params), "esri:%d", cs - TTCS_ESRI);
 		return &rv;
 	}
 	if (cs > TTCS_EPSG) {
-	  std::snprintf(params, sizeof(params), "+init=epsg:%d", cs - TTCS_EPSG);
-      if (epsg_labels.find(cs - TTCS_EPSG) != epsg_labels.end()) {
-        rv.prjname = epsg_labels[cs - TTCS_EPSG];
-      } else {
-        thcs_get_label(params).copy(prjname, 200, 0);
-      }
+	  std::snprintf(params, sizeof(params), "epsg:%d", cs - TTCS_EPSG);
 		return &rv;
 	}
   if (cs >= 0) return &(thcsdata_table[cs]);
@@ -154,7 +142,6 @@ void thcs_add_cs(char * id, char * proj4id)
   if (!th_is_extkeyword(id)) ththrow("invalid cs identifier -- {}", id);
   thcs_check(proj4id);
   thcsdata * pd = &(*thcs_custom_data.insert(thcs_custom_data.end(), thcsdata()));
-  pd->prjspec = "";
   pd->params = thdb.strstore(proj4id);
   pd->prjname = thdb.strstore(id);
   pd->dms = thcs_islatlong(proj4id);
