@@ -27,7 +27,6 @@
  
 #include "thdb2d.h"
 #include "thdatabase.h"
-#include "thparse.h"
 #include "thmap.h"
 #include "thscrap.h"
 #include "thsurvey.h"
@@ -35,6 +34,7 @@
 #include "thconfig.h"
 #include <list>
 #include <algorithm>
+#include <cstring>
 #include "thmapstat.h"
 
 void thdb2d::insert_basic_maps(thdb2dxm * fmap, thmap * map, int mode, int level, thdb2dmi_shift shift) {
