@@ -31,7 +31,7 @@
 
 
 #include "th2ddataobject.h"
-#include "thparse.h"
+#include "thstok.h"
 #include "thdb2dpt.h"
 #include "thobjectname.h"
 
@@ -510,6 +510,8 @@ class thpoint : public th2ddataobject {
 
   void check_extra();
 
+  thdate * get_date();
+
   /**
    * Standard constructor.
    */
