@@ -30,7 +30,6 @@
 #include "thconfig.h"
 #include <stdio.h>
 #include <string.h>
-#include "thparse.h"
 #include "thdatabase.h"
 #include "thdataobject.h"
 #include "thsurvey.h"
@@ -38,6 +37,7 @@
 #include <vector>
 #include "thchenc.h"
 #include "thmap.h"
+#include "therion.h"
 
 #include <fmt/printf.h>
 
