@@ -33,9 +33,9 @@
 #include "thcsdata.h"
 #include <cmath>
 #include "thdatareader.h"
-#include "thparse.h"
 #include "thdb1d.h"
 #include "thinfnan.h"
+#include "therion.h"
 #include <algorithm>
 #include <filesystem>
 
